@@ -66,8 +66,11 @@ format_priors <- function(lavpartable, mat) {
   if (grepl("var", mat)) {
     mat <- gsub("var", "", mat)
     prisel <- lavpartable$row == lavpartable$col
-  } else if (grepl("off", mat)) {
-    mat <- gsub("off", "", mat)
+  } else if (grepl("psioff", mat)) {
+    mat <- "lvrho"
+    prisel <- lavpartable$row != lavpartable$col
+  } else if (grepl("thetaoff", mat)) {
+    mat <- "rho"
     prisel <- lavpartable$row != lavpartable$col
   } else {
     prisel <- rep(TRUE, length(lavpartable$row))
@@ -94,14 +97,28 @@ format_priors <- function(lavpartable, mat) {
       param2 <- rep(NA, length(param1))
     }
 
+    ## check that var/sd/prec is same for all
+    powargs <- sapply(prisplit, tail, 1)
+    if (any(grepl("\\[", powargs))) {
+      if (length(unique(powargs)) > 1) stop(paste0("blavaan ERROR: In matrix ", mat, ", all priors must be placed on either vars, sds, or precisions."))
+    }
+    powpar <- 1
+    powarg <- powargs[1]
+    if (grepl("\\[var\\]", powarg)) {
+      powpar <- 2
+    } else if (!grepl("\\[sd\\]", powarg)) {
+      powpar <- -2
+    }
+    
     param1 <- array(as.numeric(param1), length(param1))
     param2 <- array(as.numeric(param2), length(param2))
   } else {
     param1 <- array(0,0)
     param2 <- array(0,0)
+    powpar <- 1
   }
   
-  return(list(p1=param1, p2=param2))
+  return(list(p1=param1, p2=param2, powpar=powpar))
 }
 
 # Check that priors match what is in the stan file
@@ -111,7 +128,6 @@ format_priors <- function(lavpartable, mat) {
 # @return nothing
 check_priors <- function(lavpartable) {
   right_pris <- sapply(dpriors(target = "stan"), function(x) strsplit(x, "[, ()]+")[[1]][1])
-
   pt_pris <- sapply(lavpartable$prior[lavpartable$prior != ""], function(x) strsplit(x, "[, ()]+")[[1]][1])
   names(pt_pris) <- lavpartable$mat[lavpartable$prior != ""]
 
@@ -384,11 +400,13 @@ stanmarg_data <- function(YX = NULL, S = NULL, N, Ng, grpnum, # data
   dat$theta_sd_shape <- pris[['p1']]
   dat$theta_sd_rate <- pris[['p2']]
   dat$len_thet_sd <- length(dat$theta_sd_rate)
+  dat$theta_pow <- pris[['powpar']]
 
   pris <- format_priors(lavpartable, "cov.xvar")
   dat$theta_x_sd_shape <- pris[['p1']]
   dat$theta_x_sd_rate <- pris[['p2']]
   dat$len_thet_x_sd <- length(dat$theta_x_sd_rate)
+  dat$theta_x_pow <- pris[['powpar']]
   
   pris <- format_priors(lavpartable, "thetaoff")
   dat$theta_r_alpha <- pris[['p1']]; dat$theta_r_beta <- pris[['p2']]
@@ -402,7 +420,8 @@ stanmarg_data <- function(YX = NULL, S = NULL, N, Ng, grpnum, # data
   dat$psi_sd_shape <- pris[['p1']]
   dat$psi_sd_rate <- pris[['p2']]
   dat$len_psi_sd <- length(dat$psi_sd_rate)
-  
+  dat$psi_pow <- pris[['powpar']]
+
   pris <- format_priors(lavpartable, "psioff")
   dat$psi_r_alpha <- pris[['p1']]; dat$psi_r_beta <- pris[['p2']]
   dat$len_psi_r <- length(dat$psi_r_alpha)
@@ -411,7 +430,8 @@ stanmarg_data <- function(YX = NULL, S = NULL, N, Ng, grpnum, # data
   dat$phi_sd_shape <- pris[['p1']]
   dat$phi_sd_rate <- pris[['p2']]
   dat$len_phi_sd <- length(dat$phi_sd_rate)
-
+  dat$phi_pow <- pris[['powpar']]
+  
   pris <- format_priors(lavpartable, "phioff")
   dat$phi_r_alpha <- pris[['p1']]; dat$phi_r_beta <- pris[['p2']]
   dat$len_phi_r <- length(dat$phi_r_alpha)
