@@ -13,7 +13,7 @@ test_that("blavaan arguments", {
   expect_error(bsem(model, data=Data, fixed.x=TRUE, seed=1, target="jags"))
 
   ## supply ordinals
-  #expect_error(bsem(model, data=Data, fixed.x=TRUE, ordered=c("y1", "x1", adapt=2, burnin=2, sample=2)))
+  expect_error(bsem(model, data=Data, fixed.x=TRUE, ordered=c("y1", "x1"), adapt=2, burnin=2, sample=2))
 
   ## unknown cp
   expect_error(bsem(model, data=Data, ov.cp="blah", fixed.x=TRUE))
@@ -36,5 +36,15 @@ test_that("blavaan arguments", {
   names(Data)[1] <- "lambda"
   model2 <- ' lambda ~ b1*x1 + b2*x2 '
   expect_error(bsem(model2, data=Data))
-              
+
+  ## one prior on variance, one on sd (for target="stan" only)
+  model3 <- ' y1 ~ x1
+              x2 ~ x1
+              y1 ~~ prior("gamma(1,.5)[sd]")*y1
+              x2 ~~ prior("gamma(1,.5)[var]")*x2 '
+  expect_error(bsem(model3, data=Data, target="stan"))
+
+  ## unknown prior
+  expect_error(bsem(model, data=Data, dp=dpriors(psi="mydist(1,.5)")))
+  
 })
